@@ -41,6 +41,8 @@
 #include <avahi-glib/glib-malloc.h>
 #endif 
 
+#include <dbus/dbus-glib-bindings.h>
+
 #include "seahorse-gpgmex.h"
 #include "seahorse-util.h"
 #include "seahorse-gconf.h"
@@ -50,19 +52,17 @@ void
 seahorse_util_show_error (GtkWindow *parent, const gchar *heading, const gchar *message)
 {
 	GtkWidget *error;
-    gchar *t;
     
 	g_return_if_fail (message);
     
-    if (heading)
-        t = g_strconcat("<big><b>", heading, "</b></big>\n\n", message, NULL);
+	error = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
+		GTK_BUTTONS_CLOSE, NULL);
+		
+	if (heading)
+        g_object_set (G_OBJECT (error), "text", heading, "secondary-text", message, NULL);
     else
-        t = g_strdup (message);
-	
-	error = gtk_message_dialog_new_with_markup (parent, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-		GTK_BUTTONS_CLOSE, t, NULL);
-    g_free (t);
-	
+        g_object_set (G_OBJECT (error), "text", message, NULL);
+        	
 	gtk_dialog_run (GTK_DIALOG (error));
 	gtk_widget_destroy (error);
 }
@@ -114,7 +114,12 @@ seahorse_util_handle_error (GError* err, const char* desc, ...)
     if (desc)
         t = g_strdup_vprintf (desc, ap);
     
-    va_end(ap);        
+    va_end(ap);    
+    
+    /* Never show an error for 'cancelled' */
+    if (err->code == DBUS_GERROR_REMOTE_EXCEPTION && err->domain == DBUS_GERROR && 
+        strstr (dbus_g_error_get_name (err), "Cancelled"))
+	    return;
     
     seahorse_util_show_error (NULL, t, err->message ? err->message : "");
     g_free(t);
