@@ -25,10 +25,11 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-#include <gnome.h>
 
 #include <panel-applet.h>
 
+#include <bonobo.h>
+
 #include <dbus/dbus-glib-bindings.h>
 
 #include <cryptui.h>
@@ -270,7 +271,7 @@ static void about_dialog_activate_link_cb (GtkAboutDialog *about,
         GtkWidget *dialog;
 	GError *error = NULL;
 	
-	if (!gnome_url_show (url, &error)) {
+	if (!g_app_info_launch_default_for_uri (url, NULL, &error)) {
 		dialog = gtk_message_dialog_new (GTK_WINDOW (about), GTK_DIALOG_MODAL, 
 		                                 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 		                                 _("Could not display URL: %s"),
@@ -362,6 +363,18 @@ display_text (gchar *title, gchar *text, gboolean editable)
     gtk_widget_show_all (dialog);
 }
 
+static void
+notification_error (const char *title, const char *detail, SeahorseApplet *sapplet, GError *err)
+{
+	/* Never show an error for 'cancelled' */
+	if (err->code == DBUS_GERROR_REMOTE_EXCEPTION && err->domain == DBUS_GERROR && 
+	    strstr (dbus_g_error_get_name (err), "Cancelled"))
+		return;
+
+	seahorse_notification_display(title, detail, FALSE, NULL,
+                                      GTK_WIDGET (sapplet));
+}
+
 static void
 encrypt_received (GtkClipboard *board, const gchar *text, SeahorseApplet *sapplet)
 {
@@ -369,6 +382,7 @@ encrypt_received (GtkClipboard *board, const gchar *text, SeahorseApplet *sapple
     gchar *enctext = NULL;
     gchar **keys = NULL;
     gboolean ret;
+    GError *err = NULL;
 
     /* No text on clipboard */
     if (!text)
@@ -382,7 +396,7 @@ encrypt_received (GtkClipboard *board, const gchar *text, SeahorseApplet *sapple
 
     /* User may have cancelled */
     if (keys && *keys) {
-        ret = dbus_g_proxy_call (dbus_crypto_proxy, "EncryptText", NULL, 
+        ret = dbus_g_proxy_call (dbus_crypto_proxy, "EncryptText", &err, 
                                 G_TYPE_STRV, keys, 
                                 G_TYPE_STRING, signer, 
                                 G_TYPE_INT, 0,
@@ -399,12 +413,11 @@ encrypt_received (GtkClipboard *board, const gchar *text, SeahorseApplet *sapple
             if (seahorse_gconf_get_boolean (DISPLAY_CLIPBOARD_ENC_KEY) == TRUE)
                 display_text (_("Encrypted Text"), enctext, FALSE);
         } else {
-            seahorse_notification_display(_("Encryption Failed"),
-                                          _("The clipboard could not be encrypted."),
-                                          FALSE,
-                                          NULL,
-                                          GTK_WIDGET(sapplet));
+        	notification_error (_("Encryption Failed"), _("The clipboard could not be encrypted."), 
+        	                    sapplet, err);
+        	g_clear_error (&err);
         }
+        
         g_strfreev(keys);
         g_free (signer);
         g_free (enctext);
@@ -429,6 +442,7 @@ sign_received (GtkClipboard *board, const gchar *text, SeahorseApplet *sapplet)
     gchar *signer = NULL;
     gchar *enctext = NULL;
     gboolean ret;
+    GError *err = NULL;
     
     /* No text on clipboard */
     if (!text)
@@ -443,7 +457,7 @@ sign_received (GtkClipboard *board, const gchar *text, SeahorseApplet *sapplet)
         return;
 
     /* Perform the signing */
-    ret = dbus_g_proxy_call (dbus_crypto_proxy, "SignText", NULL, 
+    ret = dbus_g_proxy_call (dbus_crypto_proxy, "SignText", &err, 
                                 G_TYPE_STRING, signer, 
                                 G_TYPE_INT, 0,
                                 G_TYPE_STRING, text,
@@ -459,11 +473,9 @@ sign_received (GtkClipboard *board, const gchar *text, SeahorseApplet *sapplet)
         if (seahorse_gconf_get_boolean (DISPLAY_CLIPBOARD_ENC_KEY) == TRUE)
             display_text (_("Signed Text"), enctext, FALSE);
     } else {
-        seahorse_notification_display(_("Signing Failed"),
-                                      _("The clipboard could not be Signed."),
-                                      FALSE,
-                                      NULL,
-                                      GTK_WIDGET(sapplet));
+        notification_error (_("Signing Failed"), _("The clipboard could not be Signed."), 
+                            sapplet, err);
+        g_clear_error (&err);
     }
     
     g_free (signer);
@@ -520,13 +532,14 @@ decrypt_text (const gchar *text, SeahorseApplet *sapplet)
     gchar *rawtext = NULL;
     gchar *signer = NULL;
     gboolean ret;
+    GError *err = NULL;
     
     if (cryptui_keyset_get_count (dbus_keyset) == 0) {
         cryptui_need_to_get_keys (dbus_keyset);
         return NULL;
     }
     
-    ret = dbus_g_proxy_call (dbus_crypto_proxy, "DecryptText", NULL,
+    ret = dbus_g_proxy_call (dbus_crypto_proxy, "DecryptText", &err,
                              G_TYPE_STRING, "openpgp",
                              G_TYPE_INT, 0,
                              G_TYPE_STRING, text,
@@ -540,11 +553,9 @@ decrypt_text (const gchar *text, SeahorseApplet *sapplet)
         
         return rawtext;
     } else {
-        seahorse_notification_display(_("Decrypting Failed"),
-                                      _("Text may be malformed."),
-                                      FALSE,
-                                      NULL,
-                                      GTK_WIDGET(sapplet));
+        notification_error (_("Signing Failed"), _("The clipboard could not be Signed."), 
+                            sapplet, err);
+        g_clear_error (&err);
         return NULL;
     }
 }
@@ -705,7 +716,7 @@ help_cb (BonoboUIComponent *uic, SeahorseApplet *sapplet, const char *verbname)
 	GtkWidget *dialog;
 	GError *error = NULL;
     
-	if (!gnome_url_show (document, &error)) {
+	if (!g_app_info_launch_default_for_uri (document, NULL, &error)) {
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, 
 		                                 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 		                                 _("Could not display URL: %s"),
@@ -1023,14 +1034,48 @@ seahorse_applet_factory (PanelApplet *applet, const gchar *iid, gpointer data)
 int 
 main (int argc, char *argv [])
 {
+    GOptionContext *context;
+    GError *error;
+    gint retval;
+
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain (GETTEXT_PACKAGE);
 
+    context = g_option_context_new ("");
+    g_option_context_add_group (context, gtk_get_option_group (TRUE));
+    g_option_context_add_group (context, bonobo_activation_get_goption_group ());
+    
+    
+
     seahorse_secure_memory_init ();
-
-    gtk_init_with_args (&argc, &argv, "seahorse-applet", NULL, GETTEXT_PACKAGE, NULL);
-
-    return panel_applet_factory_main ("OAFIID:GNOME_SeahorseApplet_Factory", 
+    
+    error = NULL; 
+ 	if (!g_option_context_parse (context, &argc, &argv, &error)) { 
+     	if (error) { 
+         	g_printerr ("Cannot parse arguments: %s.\n", 
+         	error->message); 
+         	g_error_free (error); 
+     	} else 
+         	g_printerr ("Cannot parse arguments.\n"); 
+         	
+     	g_option_context_free (context); 
+     	
+     	return 1; 
+ 	}
+    
+    gtk_init (&argc, &argv);
+    
+    if (!bonobo_init (&argc, argv)) {
+        g_printerr ("Cannot initialize bonobo.\n");
+        return 1;
+    }
+    
+    retval =  panel_applet_factory_main ("OAFIID:GNOME_SeahorseApplet_Factory", 
                                       SEAHORSE_TYPE_APPLET, seahorse_applet_factory, NULL);
+                                      
+    g_option_context_free (context);
+    
+    return retval;
+
 }
