@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: seahorse-extension.c 2263 2008-07-06 02:40:47Z sadam $
+ *  $Id: seahorse-extension.c 2498 2008-09-13 22:13:48Z nnielsen $
  */
 
 #include "config.h"
@@ -228,6 +228,24 @@ seahorse_extension_register_type (GTypeModule *module)
 	return type;
 }
 
+static void
+notification_error (const gchar *title, const gchar *details, GError *err)
+{
+	/* Never show an error for 'cancelled' */
+	if (err->code == DBUS_GERROR_REMOTE_EXCEPTION && err->domain == DBUS_GERROR && 
+	    strstr (dbus_g_error_get_name (err), "Cancelled"))
+		return;
+
+        dbus_g_proxy_call (dbus_key_proxy, "DisplayNotification", NULL,
+                           G_TYPE_STRING, title,
+                           G_TYPE_STRING, details,
+                           G_TYPE_STRING, NULL,
+                           G_TYPE_BOOLEAN,   FALSE,
+                           G_TYPE_INVALID,
+                           G_TYPE_INVALID);
+
+}
+
 static void 
 encrypt_seahorse_cb (GtkAction *action, EphyWindow *window)
 {
@@ -366,13 +384,14 @@ decrypt_text (const gchar *text)
     gchar *rawtext = NULL;
     gchar *signer = NULL;
     gboolean ret;
+    GError *err = NULL;
     
         if (cryptui_keyset_get_count (dbus_keyset) == 0) {
             cryptui_need_to_get_keys (dbus_keyset);
             return NULL;
         }
 
-    ret = dbus_g_proxy_call (dbus_crypto_proxy, "DecryptText", NULL,
+    ret = dbus_g_proxy_call (dbus_crypto_proxy, "DecryptText", &err,
                              G_TYPE_STRING, "openpgp",
                              G_TYPE_INT, 0,
                              G_TYPE_STRING, text,
@@ -386,13 +405,8 @@ decrypt_text (const gchar *text)
         
         return rawtext;
     } else {
-        dbus_g_proxy_call (dbus_key_proxy, "DisplayNotification", NULL,
-                           G_TYPE_STRING, _("Decrypting Failed"),
-                           G_TYPE_STRING, _("Text may be malformed."),
-                           G_TYPE_STRING, NULL,
-                           G_TYPE_BOOLEAN,   FALSE,
-                           G_TYPE_INVALID,
-                           G_TYPE_INVALID);
+        notification_error (_("Decrypting Failed"), _("Text may be malformed."), err);
+        g_clear_error (&err);
         return NULL;
     }
 }
